@@ -300,6 +300,7 @@ primary key (category_id)
 create table ax_story_category_locs (
 category_id          INTEGER                        not null,
 location_id          INTEGER                        not null,
+primary key (category_id, location_id),
 foreign key (location_id)
       references ax_content_location (location_id),
 foreign key (category_id)
@@ -311,6 +312,10 @@ user_id              VARCHAR(64)                    not null,
 org_id               INTEGER                        not null default 0,
 password             LONG VARCHAR,
 full_name            LONG VARCHAR,
+honorific_prefix     LONG VARCHAR,
+first_name           LONG VARCHAR,
+mid_names            LONG VARCHAR,
+last_name            LONG VARCHAR,
 user_type            VARCHAR(10)                    not null default 'user' 
       check (user_type in ('user','sys')),
 email                LONG VARBINARY,
@@ -321,8 +326,13 @@ mobile               LONG VARBINARY,
 last_login           DATE,
 total_logins         INTEGER                        not null default 0,
 limit_logins         INTEGER                        not null default 0,
-enabled              SMALLINT                       not null default true,
 auth_code            LONG VARCHAR,
+passwd_forever       SMALLINT                       not null default 0,
+passwd_expiry        DATE                           not null,
+passwd_history       LONG VARCHAR,
+passwd_failures      INTEGER                        not null default 0,
+locked               SMALLINT                       not null default 0,
+enabled              SMALLINT                       not null default true,
 primary key (user_id),
 foreign key (org_id)
       references ax_organisation (org_id)
@@ -507,6 +517,7 @@ create table ax_story_location (
 story_id             INTEGER                        not null,
 location_id          INTEGER                        not null,
 display_order        INTEGER                        not null default 999,
+primary key (story_id, location_id),
 foreign key (story_id)
       references ax_story (story_id),
 foreign key (location_id)
@@ -650,6 +661,7 @@ foreign key (schema_name, element_id)
 create table ax_microsite_story (
 story_id             INTEGER                        not null,
 microsite_name       VARCHAR(64)                    not null,
+primary key (story_id, microsite_name),
 foreign key (story_id)
       references ax_story (story_id),
 foreign key (microsite_name)
