@@ -1,7 +1,7 @@
 /*==============================================================*/
 /* Database name:  axyl                                         */
 /* DBMS name:      PostgreSQL 7                                 */
-/* Created on:     28/02/2005 8:12:28 p.m.                      */
+/* Created on:     15/10/2005 7:13:11 p.m.                      */
 /*==============================================================*/
 
 
@@ -770,7 +770,8 @@ constraint PK_AX_MICROSITE_PAGE_PLUGIN primary key (plugin_id)
 /*==============================================================*/
 create table ax_microsite_story (
 microsite_name       TEXT                 not null,
-story_id             INT4                 not null
+story_id             INT4                 not null,
+constraint PK_AX_MICROSITE_STORY primary key (microsite_name, story_id)
 );
 
 /*==============================================================*/
@@ -948,7 +949,8 @@ comment on column ax_story_category.has_multimedia is
 /*==============================================================*/
 create table ax_story_category_locs (
 category_id          INT4                 not null,
-location_id          INT4                 not null
+location_id          INT4                 not null,
+constraint PK_AX_STORY_CATEGORY_LOCS primary key (category_id, location_id)
 );
 
 comment on table ax_story_category_locs is
@@ -960,7 +962,8 @@ comment on table ax_story_category_locs is
 create table ax_story_location (
 story_id             INT4                 not null,
 location_id          INT4                 not null,
-display_order        INT4                 not null default 999
+display_order        INT4                 not null default 999,
+constraint PK_AX_STORY_LOCATION primary key (story_id, location_id)
 );
 
 comment on table ax_story_location is
@@ -1004,8 +1007,12 @@ user_id              TEXT                 not null,
 org_id               INT4                 not null default 0,
 password             TEXT                 null,
 full_name            TEXT                 null,
+honorific_prefix     TEXT                 null,
+first_name           TEXT                 null,
+mid_names            TEXT                 null,
+last_name            TEXT                 null,
 user_type            TEXT                 not null default 'user' 
-      constraint CKC_USER_TYPE_AX_USER check (user_type in ('user','sys')),
+      constraint CKC_USER_TYPE_AX_USER check (user_type in ('user','sys','remote')),
 email                TEXT                 null,
 address              TEXT                 null,
 phone                TEXT                 null,
@@ -1014,8 +1021,13 @@ mobile               TEXT                 null,
 last_login           TIMESTAMP WITH TIME ZONE null,
 total_logins         INT4                 not null default 0,
 limit_logins         INT4                 not null default 0,
-enabled              BOOL                 not null default true,
 auth_code            TEXT                 null,
+passwd_forever       BOOL                 not null default false,
+passwd_expiry        TIMESTAMP WITH TIME ZONE null,
+passwd_history       TEXT                 null,
+passwd_failures      INT4                 not null default 0,
+locked               BOOL                 not null default false,
+enabled              BOOL                 not null default true,
 constraint ax_user_pkey primary key (user_id)
 );
 
