@@ -1,6 +1,6 @@
-#! /bin/sh
+#! /bin/bash
 #
-# Remove an Apache ServerAlias from an existing Virtual Host entry
+# Remove an Apache ServerAlias from an existing Virtual Host entry.
 # P Waite
 set -e
 
@@ -11,8 +11,7 @@ THIS=`basename $0`
 # Acquire the local configuration..
 CONFDIR=/etc/axyl
 CONF=${CONFDIR}/axyl.conf
-if [ ! -f $CONF ]
-then
+if [ ! -f $CONF ] ; then
   echo "Axyl configuration file $CONF not found!"
   exit 2
 else
@@ -26,15 +25,13 @@ fi
 
 # Parameters..
 # Must have all parms for this..
-if [ $# -lt 2 ]
-then
+if [ $# -lt 2 ] ; then
   echo "usage: $THIS servername serveralias [silent]"
   exit 3
 fi
 VSERVERNAME=$1
 SERVERALIAS=$2
-if [ "$3" != "" ]
-then
+if [ "$3" != "" ] ; then
   MODE=$3
 else
   MODE="interactive"
@@ -42,8 +39,7 @@ fi
 
 # Files..
 # New format or old?
-if [ -e ${APACHE_CONFDIR}/conf.d ]
-then
+if [ -e ${APACHE_CONFDIR}/conf.d ] ; then
   CONF=${APACHE_CONFDIR}/conf.d/${VSERVERNAME}.conf
   CONF_OLD=${CONF}.axyl-old
 else
