@@ -629,79 +629,5 @@ class Link extends RenderableObject {
   }
 } // Link
 
-// ----------------------------------------------------------------------
-/**
-* RugbyLive Action link
-*
-* Note: this class is only of use for the RugbyLive framework.
-* A clickable link, which is dedicated to our 'nav_action' methodology
-* of routing the user to the appropriate page as used in rugbyvu.
-* @access private
-* @package buttons
-*/
-class action_link extends RenderableObject {
-  /** The label to display for the link */
-  var $label = "";
-  /** Nav Action parameter string */
-  var $parms = "";
-  /** Font settings for link text */
-  var $font = "";
-  /** Nav Action action string */
-  var $action = "";
-  /** Status bar text when link moused over */
-  var $linkover_text = "";
-  /**
-  * Constructor
-  * @param string  $action        The nav-action action to perform
-  * @param string  $label         The text to display for the link
-  * @param string  $parms         The parameter string to sned with the action
-  * @param string  $font          Font settings to use with label
-  * @param string  $linkover_text Text to show in status bar on mouseover
-  */
-  function action_link($action, $label="", $parms="", $font="", $linkover_text="") {
-    $this->action = $action;
-    $this->label = $label;
-    $this->parms = $parms;
-    $this->font = $font;
-    if ($linkover_text == "") $this->linkover_text = $label;
-    else $this->linkover_text = $linkover_text;
-  }
-  // ....................................................................
-  /**
-  * Sets the font
-  * Deprecated. Sets the font to use with the link text. Better
-  * to use a stylesheet these days.
-  */
-  function set_font($font) {
-    $this->font = $font;
-    return $this;$this->pagetext .= " " . $pglink->wml();
-  }
-  // ....................................................................
-  /**
-  * Use render() to render this element in your page.
-  * Renders the reset button as WML.
-  * @see render()
-  * @return string WML rendering of button
-  */
-  function wml() {
-    $href = "nav_action.php?action=" . $this->action . "&amp;" . "parms=" . $this->parms;
-    $link = new Link($href, $this->label);
-    return $link->wml();
-  }
-  // ....................................................................
-  /**
-  * Use render() to render this element in your page.
-  * Renders the reset button as HTML.
-  * @see render()
-  * @return string HTML rendering of button
-  */
-  function html() {
-    $href = "javascript:set_nav_parms('" . $this->parms . "'); btn_press('" . $this->action . "');";
-    $link = new Link($href, $this->label, "", "", $this->font);
-    $link->set_linkover_text($this->linkover_text);
-    return $link->html();
-  }
-} // action_link class
-
 // ----------------------------------------------------------------------
 ?>
\ No newline at end of file
