@@ -521,6 +521,36 @@ class datasources {
   } // lock
   // ....................................................................
   /**
+  * Used to escape particular characters (typically the single quote) so
+  * that they can form part of the database data, rather than being
+  * interpreted as command syntax.
+  * @param string $str
+  * @return string The same string with appropriate chars escaped.
+  */
+  function escape_string($str="") {
+    if (isset($this->database[$this->db_name_selected])) {
+      $str = $this->database[$this->db_name_selected]->escape_string($str);
+    }
+    return $str;
+  } // escape_string
+  // ....................................................................
+  /**
+  * Used to unescape escaped characters (typically the single quote) so
+  * that they are as they were before having the escape_string() method
+  * applied.
+  * Note that some databases do not need this to be done - they
+  * unescape escaped content when data is returned.
+  * @param string $str
+  * @return string The same string with escaped chars UN-escaped.
+  */
+  function unescape_string($str="") {
+    if (isset($this->database[$this->db_name_selected])) {
+      $str = $this->database[$this->db_name_selected]->unescape_string($str);
+    }
+    return $str;
+  } // unescape_string
+  // ....................................................................
+  /**
   * Given an Axyl SQL query object, build the SQL string from it
   * in suitable format for the currently connected database server.
   * @param object $sqlquery An Axyl query object
@@ -829,6 +859,24 @@ class database {
     return true;
   }
   // ....................................................................
+  /** This method may be over-ridden in the child class. The default is
+  * to apply a rather simplistic SQL-standard transformation of single
+  * quote to doubled-up single-quote ' --> ''.
+  */
+  function escape_string($str) {
+    if (is_string($str)) {
+      $str = str_replace("'", "''", $str);
+    }
+    return $str;
+  }
+  // ....................................................................
+  /** This method may be over-ridden in the child class. The default
+  * action is to simply do nothing.
+  */
+  function unescape_string($str) {
+    return $str;
+  }
+  // ....................................................................
   /**
   * Given an Axyl SQL query object, build the SQL string from it
   * in suitable format for the currently connected database server.
