@@ -36,8 +36,8 @@
 */
 class db_mssql_server extends database {
   /** Constructor */
-  function db_mssql_server($name="", $user="", $passwd="", $host="", $port=0) {
-    $this->database($name, $user, $passwd, $host, $port);
+  function db_mssql_server($name="", $user="", $passwd="", $host="", $port=0, $enc="", $datestyle="") {
+    $this->database($name, $user, $passwd, $host, $port, $enc, $datestyle);
     $this->type = "mssql_server";
   }
   // ....................................................................
