@@ -269,6 +269,40 @@ class db_postgres extends database {
   }
   // ....................................................................
   /**
+  * Used to escape particular characters (typically the single quote) so
+  * that they can form part of the database data, rather than being
+  * interpreted as command syntax. Note that this implementation makes
+  * sure the string has none of the deprecated backslashes added by the
+  * old addslashes() function, before escaping the content properly.
+  * @param string $str
+  * @return string The same string with appropriate chars escaped.
+  */
+  function escape_string($str="") {
+    if (is_string($str)) {
+      $str = pg_escape_string(stripslashes($str));
+    }
+    return $str;
+  } // escape_string
+  // ....................................................................
+  /**
+  * Used to unescape any escaped characters. Normally databases require
+  * nothing to be done here for single-quote escapes, as they return the
+  * data already unescaped.
+  * Note: for Postgres we have been using add/stripslashes to escape
+  * string data. To remedy a security issue this is no longer used, but
+  * we need to apply a stripslashes here to removed slashes from any
+  * legacy data out there.
+  * @param string $str
+  * @return string The same string with escaped chars UN-escaped.
+  */
+  function unescape_string($str="") {
+    if (is_string($str)) {
+      $str = stripslashes($str);
+    }
+    return $str;
+  } // unescape_string
+  // ....................................................................
+  /**
   * Given an Axyl SQL query object, build the SQL string from it
   * in suitable format for the currently connected database server.
   * @param pointer $sqlquery Pointer to an Axyl query object
