@@ -43,6 +43,20 @@ include_once("form-defs.php");
 //  $myfield = $Fld->render();
 //  ...
 //  ... more htmlareas as required ...
+//
+// Set this global externally to override. We choose the default to
+// be Xinha, as this is a more recent fork of htmlarea.
+if (!isset($wysiwyg_editor)) {
+  $wysiwyg_editor = "xinha";
+}
+
+// Locations of the editors javaswcript trees
+$wysiwyg_editor_dirs = array(
+  "htmlarea" => "js/htmlarea",
+  "xinha"    => "js/xinha"
+  );
+// The one we will be using here..
+$wysiwyg_editor_dir = $wysiwyg_editor_dirs[$wysiwyg_editor];
 
 // ----------------------------------------------------------------------
 /**
@@ -144,16 +158,16 @@ class htmlarea extends HTMLObject {
   */
   function initialise() {
     debug_trace($this);
-    global $RESPONSE, $LIBDIR;
+    global $RESPONSE, $LIBDIR, $wysiwyg_editor_dir;
     // One-time-only javascript for all HTMLAreas on page..
     if (!$this->init_done) {
       $RESPONSE->head->add_named_script(
-          "_editor_url = \"$LIBDIR/js/htmlarea/\";\n"
+          "_editor_url = \"$LIBDIR/$wysiwyg_editor_dir\";\n"
         . "_editor_lang = \"en\";\n",
         "htmlarea settings"
         );
       $RESPONSE->set_onload("HTMLArea.init();");
-      $RESPONSE->add_scriptsrc("$LIBDIR/js/htmlarea/htmlarea.js");
+      $RESPONSE->add_scriptsrc("$LIBDIR/$wysiwyg_editor_dir/htmlarea.js");
 
       foreach ($this->loaded_plugins as $plugin) {
         $RESPONSE->add_named_script("HTMLArea.loadPlugin(\"$plugin\");\n", "htmlarea");
@@ -633,8 +647,8 @@ class form_wysiwygfield extends form_memofield {
   * @access private
   */
   function register() {
-    global $HTMLAREA, $RESPONSE, $LIBDIR;
-    if (isset($RESPONSE) && file_exists($RESPONSE->site_docroot."$LIBDIR/js/htmlarea/htmlarea.js")) {
+    global $HTMLAREA, $RESPONSE, $LIBDIR, $wysiwyg_editor_dir;
+    if (isset($RESPONSE) && file_exists($RESPONSE->site_docroot."$LIBDIR/$wysiwyg_editor_dir/htmlarea.js")) {
       $wysiwyged = $this->wysiwyg_id . "_ed";
       $wysiwygconfig = $this->wysiwyg_id . "_config";
 
