@@ -30,6 +30,12 @@
 /*                                                                      */
 /* (see recmaint-defs.php for usage)                                    */
 /*                                                                      */
+/* Note: For javascript aficianados, the following vars are inserted by */
+/* recmaint-defs.php code as globals, and hence are not in this file:   */
+/*     var keyfield = new Array();                                      */
+/*     var curid = new Array();                                         */
+/*     var newid = new Array();                                         */
+/*                                                                      */
 /* ******************************************************************** */
 var field_delim = '^_^';
 var record_delim = '~_~';
@@ -54,6 +60,7 @@ function disable(fm, mode, prefix) {
   }
 }
 function getcurid(fm, pfx) {
+  var ix = 0;
   curid[pfx] = -1;
   var keycombo = findFieldObj(fm, keyfield[pfx]);
   if (keycombo != null && keycombo.options.length > 0) {
@@ -100,8 +107,8 @@ function comboMove(fm, fname, direction) {
     var ix = combo.selectedIndex;
     if (direction == 'up') {
       if (ix == 0) return;
-      tmpval = combo.options[ix - 1].value;
-      tmptxt = combo.options[ix - 1].text;
+      var tmpval = combo.options[ix - 1].value;
+      var tmptxt = combo.options[ix - 1].text;
       combo.options[ix - 1].value = combo.options[ix].value;
       combo.options[ix - 1].text  = combo.options[ix].text;
       combo.options[ix].value = tmpval;
@@ -185,7 +192,8 @@ function getField(fm, fname) {
 function updateFields(fm, id, pfx) {
   var datObj = eval(pfx + 'dat_' + fm);
   if (datObj != null && datObj[id] != null) {
-    rec = datObj[id].data;
+    var rec = datObj[id].data;
+    var val = '';
     for (var fld in rec) {
       val = getField(fm, fld);
       setValue(fm, fld, id, val, pfx);
@@ -195,7 +203,8 @@ function updateFields(fm, id, pfx) {
 function displayFields(fm, id, pfx) {
   var datObj = eval(pfx + 'dat_' + fm);
   if (datObj != null && datObj[id] != null) {
-    rec = datObj[id].data;
+    var rec = datObj[id].data;
+    var val = '';
     for (var fld in rec) {
       val = getValue(fm, fld, id, pfx);
       setField(fm, fld, val);
@@ -226,9 +235,9 @@ function changedValue(fm, fld, pfx) {
 }
 function changeRecord(fm, keycombo, pfx) {
   if (keycombo.options.length > 0) {
-    ix = keycombo.selectedIndex;
+    var ix = keycombo.selectedIndex;
     if (ix == -1) ix = 0;
-    id = keycombo.options[ix].value;
+    var id = keycombo.options[ix].value;
     displayFields(fm, id, pfx);
     curid[pfx] = id;
   }
@@ -257,9 +266,9 @@ function deleteRecord(fm, pfx) {
         if (postDels.value != '') postDels.value += field_delim;
         postDels.value += curid[pfx];
       }
-      datObj = eval(pfx + 'dat_' + fm);
+      var datObj = eval(pfx + 'dat_' + fm);
       datObj[curid[pfx]] = null;
-      ix = keycombo.selectedIndex;
+      var ix = keycombo.selectedIndex;
       keycombo.options[ix] = null;
       if (ix > 0) keycombo.selectedIndex = (ix - 1);
       getcurid(fm, pfx);
@@ -279,7 +288,7 @@ function addRecord(fm, pfx) {
     if (newFunc != null) {
       newFunc(newID);
       var newopt = new Option('<new item>', newID);
-      newix = keycombo.options.length;
+      var newix = keycombo.options.length;
       keycombo.options[newix] = newopt;
       keycombo.selectedIndex = newix;
       changeRecord(fm, keycombo, pfx);
@@ -289,7 +298,7 @@ function addRecord(fm, pfx) {
   }
 }
 function storeRecords(fm, pfx) {
-  var stored=false;
+  var stored=false, rec = '', datastr = '';
   var datObj = eval(pfx + 'dat_' + fm);
   if (datObj != null) {
     var postData = eval('document.forms.' + fm + '.' + pfx + 'recmaintpost_data');
@@ -335,18 +344,19 @@ function datarec(keyid, data, pfx) {
   curid[pfx] = keyid;
 }
 function limitInt(fld, lo, hi) {
-  val = fld.value;
-  re = /\$|,|%/g;
-  valnew = val.replace(re, "");
-  vali = parseInt(valnew);
+  var val = fld.value;
+  var re = /\$|,|%/g;
+  var valnew = val.replace(re, "");
+  var vali = parseInt(valnew);
   if (vali < lo || isNaN(vali)) vali = lo;
   else if (vali > hi) vali = hi;
   fld.value = vali;
 }
 function urlEncode(str) {
-  len = str.length;
-  res = new String();
-  charOrd = new Number();
+  var len = str.length;
+  var res = new String();
+  var charOrd = new Number();
+  var i = 0, chk = '', hexValStr = '';
   for (i = 0; i < len; i++) {
     chk = str.substr(i, 3);
     if (chk == '%0D'||chk == '%0A'||chk == '%27') {
@@ -377,6 +387,6 @@ function urlEncode(str) {
   return res;
 }
 function urlDecode(str) {
-  mystr = unescape(mystr);
+  var mystr = unescape(mystr);
   return mystr;
 }
\ No newline at end of file
