@@ -1128,25 +1128,28 @@ class DB_schema extends schema {
   // ....................................................................
   /** Acquire the Postgres database version. We make some gross assumptions
   * here with regard to standard local Postgres setup. Change as necessary.
-  * Currently we have a shot at either the Debian standard location which
-  * is '/usr/lib/postgresql', or the 'other' standard of '/usr/bin'.
-  * To-do: acquire Postgres binaries location in a more robust way.
+  * Currently we are assuming the Debian standard location which can be
+  * over-ridden with a passed-in parameter. Then we try for the newer multi-
+  * version Postgresql arrangement where the major.minor version number
+  * (eg. '8.2') is used as the root directory, before falling back to the
+  * older single-version arrangement.
   */
-  function getversion() {
-    $vstr = 7.3;
-    $pg_bin = "";
-    $pg_paths = array(
-        "/usr/lib/postgresql/bin",
-        "/usr/bin",
-        "/usr/local/pgsql/bin"
-        );
-    // Find Postgres executable directory..
-    foreach ($pg_paths as $pg_path) {
-      if (file_exists("$pg_path/pg_ctl")) {
-        $pg_bin = $pg_path;
-        break;
-      }
+  function getversion($rootdir="") {
+    $vstr = 7.4;
+    $pg_root =  ($rootdir == "") ? "/usr/lib/postgresql" : $rootdir;
+    $pg_bin = "$pg_root/bin";
+
+    # Reassign pg_root if we have multiversion hierarchies..
+    $dirlisting = get_dirlist($pg_root, false, "/[0-9]+.[0-9]+/");
+    if (count($dirlisting) > 0) {
+      sort($dirlisting, SORT_NUMERIC);
+      reset($dirlisting);
+      $pg_root = array_pop($dirlisting);
     }
+    
+    # Set the postgres binaries dir..    
+    $pg_bin = "$pg_root/bin";
+    
     // Get the database version..
     if (file_exists("$pg_bin/pg_config")) {
       $vbits = explode(" ", shell_exec("$pg_bin/pg_config --version"));
