@@ -76,14 +76,19 @@ class transaction {
   */
   function begin($mode=ROLLBACK_ON_FAIL) {
     global $RESPONSE;
-    if ($RESPONSE->db_backed && !$this->open) {
-      $RESPONSE->datasource->begin_transaction();
-      $this->open = true;
-      $this->mode = $mode;
-      $this->failed = false;
-      $this->failed_msg = "";
-      if (debugging()) {
-        debugbr("TOK: Start transaction.", DBG_SQL);
+    if ($RESPONSE->db_backed) {
+      if (!$this->open) {
+        $RESPONSE->datasource->begin_transaction();
+        $this->open = true;
+        $this->mode = $mode;
+        $this->failed = false;
+        $this->failed_msg = "";
+        if (debugging()) {
+          debugbr("TOK: Start transaction.", DBG_SQL);
+        }
+      }
+      else {
+        debugbr("TWARN: Nested transactions are not supported", DBG_SQL);
       }
     }
   }
@@ -453,7 +458,7 @@ class sqlquery {
         if (substr($val, 0, 1) == "'") $val = substr($val, 1);
         if (substr($val, -1) == "'") $val = substr($val, 0, strlen($val) - 1);
       }
-      $val = addslashes($val);
+      $val = $RESPONSE->datasource->escape_string($val);
       $this->fields->add($field, "'$val'");
     }
   } // set
@@ -559,6 +564,9 @@ class dbquery extends sqlquery {
         if (preg_match("/(^select|^\(select)/i", $this->sql)) {
           $this->rowcount = $RESPONSE->datasource->numrows($this->rid);
         }
+        else {
+          $this->rowcount = $RESPONSE->datasource->affectedrows($this->rid);
+        }
         $this->rowno = 0;
         $this->hasdata = ($this->rowcount > 0);
       }
@@ -895,7 +903,9 @@ class dbrecords extends dbrows {
   /**
   * Get field content
   * Return the field content from the current database array (row).
-  * If the value is a string, then stripslashes is done automatically.
+  * If the value is a string, then unescape_string() is done automatically.
+  * Note that in most databases, string data does not need to be
+  * unescaped, and so this method will vary depending on DB flavour.
   * @param string $fieldname The name of the field to return value of
   * @return mixed Value of the named field
   */
@@ -906,7 +916,7 @@ class dbrecords extends dbrows {
     if ($this->rid) {
       $value = $this->rawfield($fieldname);
       if (is_string($value)) {
-        $value = stripslashes($value);
+        $value = $RESPONSE->datasource->unescape_string($value);
       }
       return $value;
     }
@@ -1108,8 +1118,13 @@ class dbseq extends dbquery {
   } // set_sequencevalue
 } // dbseq class
 
-// ######################################################################
-// Utility functions..
+/** ####################################################################
+* UTILITY FUNCTIONS
+* These are mainly provided to give you a convenient 'short-hand' way
+* of accessing database query methods, without having to specify the
+* full path to the method via the $RESPONSE object etc. It looks nicer.
+*/
+
 /**
 * Execute a DB command
 * A wrapper which caters for the 'command' type of SQL
@@ -1224,6 +1239,52 @@ function rollback() {
   return $result;
 } // rollback
 
+// ......................................................................
+/**
+* Return true or false for boolean data returned by the current DB. This
+* is to provide for boolean compatibility across all DBs.
+* @param mixed $db_value Data to be interpreted as either true or false
+* @return bool true of false
+*/
+function bool_from_db_value($db_value) {
+  global $RESPONSE;
+  return $RESPONSE->datasource->bool_from_db_value($db_value);
+} // bool_from_db_value
+
+// ......................................................................
+/**
+* Return boolean data compatible with the current DB, from boolean. This
+* is to provide for boolean compatibility across all DBs.
+* @param bool $bool Booean true or false to be returned as DB value
+* @return mixed Db-compatible boolean equivalent value
+*/
+function db_value_from_bool($bool) {
+  global $RESPONSE;
+  return $RESPONSE->datasource->db_value_from_bool($bool);
+} // db_value_from_bool
+
+// ......................................................................
+/**
+* Escape a string according to the requirements of the current DB.
+* @param string $str String to be escaped.
+* @return string Escaped version of the string
+*/
+function escape_string($str) {
+  global $RESPONSE;
+  return $RESPONSE->datasource->escape_string($str);
+} // escape_string
+
+// ......................................................................
+/**
+* Unescape a string according to the requirements of the current DB.
+* @param string $str String to be unescaped.
+* @return string Unescaped version of the escaped string
+*/
+function unescape_string($str) {
+  global $RESPONSE;
+  return $RESPONSE->datasource->unescape_string($str);
+} // unescape_string
+
 // ----------------------------------------------------------------------
 // LOCKING
 /**
