@@ -808,7 +808,7 @@ class WMLdeck extends RenderableObject {
     $s .= "</wml>";
 
     // Set the length..
-    $this->wml_len = strlen($wml);
+    $this->wml_len = strlen($this->wml);
 
     // Output the header for wml length..
     Header("Content-Length: " . $this->wml_len);
