@@ -66,6 +66,31 @@ if (!isset($LIBDIR)) {
   }
 }
 
+// -----------------------------------------------------------------------
+/* CUSTOM USER AUTHENTICATION */
+/**
+ * Here you can define a custom function for authenticating a user password.
+ * After doing this go to the Control Panel and set the password encryption
+ * to the 'Custom' setting so that the system will use this function.
+ * @param string $submitted_passwd The password as submitted by the user.
+ * @param string $actual_passwd The actual (possibly encoded) password stored.
+ * @return boolean True if the submitted password is good, else false
+ */
+function custom_authenticate_password($submitted_passwd, $actual_passwd) {
+  return ($submitted_passwd === $actual_passwd);
+}
+/**
+ * Here you can define a custom function for generating a user password.
+ * After doing this go to the Control Panel and set the password encryption
+ * to the 'Custom' setting so that the system will use this function.
+ * @param string $password The un-encrypted password.
+ * @param string $salt Optional salt for salted md5 encrypted passwords
+ * @return string The encrypted password.
+ */
+function custom_generate_password($password, $salt="") {
+  return ($password);
+}
+
 // -----------------------------------------------------------------------
 /*
 * THE RESPONSE OBJECT
@@ -76,6 +101,18 @@ if (!isset($LIBDIR)) {
 */
 include_once("response-defs.php");
 
+// -----------------------------------------------------------------------
+// Check database is defined for remote authentication..
+if (isset($RESPONSE) && $USER_AUTH_DBNAME != NOT_MAPPED) {
+  if (!$RESPONSE->select_database($USER_AUTH_DBNAME)) {
+    log_sys("remote authentication DB '$USER_AUTH_DBNAME' failed "
+          . "test connection: is it defined in application.xml?"
+          );
+  }
+  // Revert to default..
+  $RESPONSE->select_database();
+} 
+
 // -----------------------------------------------------------------------
 /**
 * USER DEFINITIONS & SETUP
@@ -84,10 +121,10 @@ include_once("response-defs.php");
 * included here.
 *
 * NOTE: If you have Microsite Features enabled (control panel), then the
-*       '$theme' variable will have possibly been set in respponse-defs.php
-*       above already. Be aware of this if you are intending to set the
-*       '$theme' variable yourself here.
+* '$theme' variable will have possibly been set in response-defs.php
+* above already. Be aware of this if you are intending to set the
+* '$theme' variable yourself here.
 */
 
 // -----------------------------------------------------------------------
-?>
+?>
\ No newline at end of file
