@@ -128,7 +128,7 @@ if ($RESPONSE->microsite_detected != "") {
   $q  = "SELECT *";
   $q .= "  FROM ax_language l, ax_microsite_story ms, ax_story s LEFT OUTER JOIN ax_user u ON u.user_id=s.story_author";
   $q .= " WHERE l.lang_id=s.lang_id";
-  $q .= "   AND ms.microsite_name='" . addslashes($RESPONSE->microsite_detected) . "'";
+  $q .= "   AND ms.microsite_name='" . escape_string($RESPONSE->microsite_detected) . "'";
   $q .= "   AND s.story_id=ms.story_id";
   $q .= "   AND s.deleted=FALSE";
 }
